AndroidAuthMessages class

Android side authentication messages.

Provides default values for all messages.

Constructors

AndroidAuthMessages({String? biometricHint, String? biometricNotRecognized, String? biometricSuccess, String? cancelButton, String? signInTitle, String? biometricRequiredTitle, String? goToSettingsButton, String? goToSettingsDescription})
const

Properties

args → Map<String, String>
no setter
biometricHint → String?
final
biometricNotRecognized → String?
final
biometricRequiredTitle → String?
final
biometricSuccess → String?
final
cancelButton → String?
final
goToSettingsButton → String?
final
goToSettingsDescription → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signInTitle → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited